pub enum SeenValues {
All {
num_values: usize,
},
Some {
values: BooleanBufferBuilder,
},
}Expand description
If the input has nulls, then the accumulator must potentially
handle each input null value specially (e.g. for SUM to mark the
corresponding sum as null)
If there are filters present, NullState tracks if it has seen
any value for that group (as some values may be filtered
out). Without a filter, the accumulator is only passed groups that
had at least one value to accumulate so they do not need to track
if they have seen values for a particular group.
Variants
All
All groups seen so far have seen at least one non-null value
Some
Fields

values: BooleanBufferBuilderTrait Implementations
Sourceimpl Debug for SeenValues
impl Debug for SeenValues